@@ -168,7 +168,10 @@ def _pin_read(pin_url, api_key, metadata):
     api_key_str = "key {}".format(api_key)
     headers = {"Authorization": api_key_str}
 
-    if str(metadata["api_version"]) != "1.0":
+    try:
+        if str(metadata["api_version"]) != "1.0":
+            raise VersionMismatchError
+    except KeyError:
         raise VersionMismatchError
 
     if metadata["type"] != "csv":
